"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const database_init_1 = __importDefault(require("../../../test/e2e/helpers/database-init"));
const test_helper_1 = require("../../../test/e2e/helpers/test-helper");
const no_logger_1 = __importDefault(require("../../../test/fixtures/no-logger"));
const util_1 = require("../../util");
let app;
let db;
beforeAll(async () => {
    db = await (0, database_init_1.default)('personal_dashboard', no_logger_1.default);
    app = await (0, test_helper_1.setupAppWithAuth)(db.stores, {
        experimental: {
            flags: {},
        },
    }, db.rawDatabase);
});
const loginUser = (email) => {
    return app.request
        .post(`/auth/demo/login`)
        .send({
        email,
    })
        .expect(200);
};
afterAll(async () => {
    await app.destroy();
    await db.destroy();
});
beforeEach(async () => {
    await db.stores.featureToggleStore.deleteAll();
    await db.stores.userStore.deleteAll();
    await db.stores.eventStore.deleteAll();
});
test('should return personal dashboard with own flags and favorited flags', async () => {
    await loginUser('other_user@getunleash.io');
    await app.createFeature('other_feature_a');
    await app.createFeature('other_feature_b');
    await loginUser('my_user@getunleash.io');
    await app.createFeature('my_feature_c');
    await app.createFeature('my_feature_d');
    await app.favoriteFeature('other_feature_b');
    await app.favoriteFeature('my_feature_d');
    const { body } = await app.request.get(`/api/admin/personal-dashboard`);
    expect(body).toMatchObject({
        flags: [
            { name: 'my_feature_d', type: 'release', project: 'default' },
            { name: 'my_feature_c', type: 'release', project: 'default' },
            { name: 'other_feature_b', type: 'release', project: 'default' },
        ],
    });
});
const createProject = async (name, user) => {
    const auditUser = {
        id: 1,
        username: 'audit user',
        ip: '127.0.0.1',
    };
    const project = await app.services.projectService.createProject({
        name,
    }, user, auditUser);
    return project;
};
const favoriteProject = async (projectName = 'default') => {
    await app.request
        .post(`/api/admin/projects/${projectName}/favorites`)
        .set('Content-Type', 'application/json')
        .expect(200);
};
test('should return personal dashboard with membered projects', async () => {
    const { body: user1 } = await loginUser('user1@test.com');
    const projectA = await createProject('Project A', user1);
    await createProject('Project B', user1);
    const { body: user2 } = await loginUser('user2@test.com');
    const projectC = await createProject('Project C', user2);
    await app.services.projectService.addAccess(projectA.id, [5], // member role
    [], [user2.id], user1);
    const { body } = await app.request.get(`/api/admin/personal-dashboard`);
    expect(body).toMatchObject({
        projects: [
            {
                name: 'Default',
                id: 'default',
                health: 100,
                memberCount: 0,
                featureCount: 0,
            },
            {
                name: projectA.name,
                id: projectA.id,
                health: 100,
                memberCount: 2,
                featureCount: 0,
            },
            {
                name: projectC.name,
                id: projectC.id,
                health: 100,
                memberCount: 1,
                featureCount: 0,
            },
        ],
    });
});
test('should return personal dashboard with user favorited projects', async () => {
    const { body: user1 } = await loginUser('user1@test.com');
    const projectA = await createProject('Project A', user1);
    await loginUser('user2@test.com');
    await favoriteProject(projectA.id);
    const { body } = await app.request.get(`/api/admin/personal-dashboard`);
    expect(body).toMatchObject({
        projects: [
            {
                name: 'Default',
                id: 'default',
                health: 100,
                memberCount: 0,
                featureCount: 0,
            },
            {
                name: projectA.name,
                id: projectA.id,
                health: 100,
                memberCount: 1,
                featureCount: 0,
            },
        ],
    });
});
test('should return projects where users are part of a group', async () => {
    const { body: user1 } = await loginUser('user1@test.com');
    const projectA = await createProject(`x${(0, util_1.randomId)()}`, user1);
    const { body: user2 } = await loginUser('user2@test.com');
    const group = await app.services.groupService.createGroup({
        name: 'groupA',
        users: [{ user: user2 }],
    }, user1);
    await app.services.projectService.addAccess(projectA.id, [5], // member role
    [], [user2.id], user1);
    await app.services.projectService.addAccess(projectA.id, [4], // owner role
    [group.id], [], user1);
    const { body } = await app.request.get(`/api/admin/personal-dashboard`);
    expect(body).toMatchObject({
        projects: [
            {
                name: 'Default',
                id: 'default',
                health: 100,
                memberCount: 0,
                featureCount: 0,
            },
            {
                name: projectA.name,
                id: projectA.id,
                health: 100,
                memberCount: 2,
                featureCount: 0,
            },
        ],
    });
});
test('should return personal dashboard project details', async () => {
    const { body: user } = await loginUser('new_user@test.com');
    const project = await createProject(`x${(0, util_1.randomId)()}`, user);
    await app.createFeature('log_feature_a', project.id);
    await app.createFeature('log_feature_b', project.id);
    await app.createFeature('log_feature_c', project.id);
    const { body } = await app.request.get(`/api/admin/personal-dashboard/${project.id}`);
    expect(body).toMatchObject({
        owners: [{}],
        roles: [{}],
        onboardingStatus: {
            status: 'first-flag-created',
            feature: 'log_feature_a',
        },
        latestEvents: [
            {
                createdBy: 'new_user@test.com',
                summary: expect.stringContaining('**new_user@test.com** created **[log_feature_c]'),
            },
            {
                createdBy: 'new_user@test.com',
                summary: expect.stringContaining('**new_user@test.com** created **[log_feature_b]'),
            },
            {
                createdBy: 'new_user@test.com',
                summary: expect.stringContaining('**new_user@test.com** created **[log_feature_a]'),
            },
            {
                createdBy: 'audit user',
                summary: expect.stringContaining(`**audit user** created project **[${project.id}]`),
            },
        ],
    });
});
test('should return Unleash admins', async () => {
    await loginUser('new_user@test.com');
    const adminRoleId = 1;
    const userService = app.services.userService;
    const admin = await userService.createUser({
        username: 'admin',
        rootRole: adminRoleId,
    });
    const admin2 = await userService.createUser({
        username: 'John',
        name: 'John Admin',
        rootRole: adminRoleId,
    });
    // service account that shouldn't be listed in the output. Service
    // accounts are enterprise functionality, so there's no service to
    // call here
    const [{ id: serviceAdminId }] = await db
        .rawDatabase('users')
        .insert({
        username: 'service_admin',
        is_service: true,
    })
        .returning('*');
    await app.services.accessService.setUserRootRole(serviceAdminId, adminRoleId);
    const { body } = await app.request.get(`/api/admin/personal-dashboard`);
    expect(body.admins).toMatchObject([
        {
            id: admin.id,
            username: admin.username,
            imageUrl: expect.stringMatching(/^https:\/\/gravatar.com/),
        },
        {
            id: admin2.id,
            name: admin2.name,
            username: admin2.username,
            imageUrl: expect.stringMatching(/^https:\/\/gravatar.com/),
        },
    ]);
});
//# sourceMappingURL=personal-dashboard-controller.e2e.test.js.map