"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PersonalDashboardService = void 0;
const util_1 = require("../../util");
class PersonalDashboardService {
    constructor(personalDashboardReadModel, projectOwnersReadModel, projectReadModel, onboardingReadModel, eventStore, featureEventFormatter, privateProjectChecker, accountStore, accessStore) {
        this.personalDashboardReadModel = personalDashboardReadModel;
        this.projectOwnersReadModel = projectOwnersReadModel;
        this.projectReadModel = projectReadModel;
        this.onboardingReadModel = onboardingReadModel;
        this.eventStore = eventStore;
        this.featureEventFormatter = featureEventFormatter;
        this.privateProjectChecker = privateProjectChecker;
        this.accountStore = accountStore;
        this.accessStore = accessStore;
    }
    getPersonalFeatures(userId) {
        return this.personalDashboardReadModel.getPersonalFeatures(userId);
    }
    async getPersonalProjects(userId) {
        const [userProjectIds, userFavoritedProjectIds] = await Promise.all([
            this.projectReadModel.getProjectsByUser(userId),
            this.projectReadModel.getProjectsFavoritedByUser(userId),
        ]);
        const projects = await this.projectReadModel.getProjectsForAdminUi({
            ids: [...new Set([...userProjectIds, ...userFavoritedProjectIds])],
            archived: false,
        });
        const normalizedProjects = projects.map((project) => ({
            id: project.id,
            name: project.name,
            health: project.health,
            memberCount: project.memberCount,
            featureCount: project.featureCount,
        }));
        return normalizedProjects;
    }
    async getProjectOwners(userId) {
        const accessibleProjects = await this.privateProjectChecker.getUserAccessibleProjects(userId);
        const filter = accessibleProjects.mode === 'all'
            ? undefined
            : new Set(accessibleProjects.projects);
        return this.projectOwnersReadModel.getAllUserProjectOwners(filter);
    }
    async getPersonalProjectDetails(userId, projectId) {
        const recentEvents = await this.eventStore.searchEvents({ limit: 4, offset: 0 }, [{ field: 'project', operator: 'IS', values: [projectId] }]);
        const onboardingStatus = await this.onboardingReadModel.getOnboardingStatusForProject(projectId);
        const formattedEvents = recentEvents.map((event) => ({
            summary: this.featureEventFormatter.format(event).text,
            createdBy: event.createdBy,
            id: event.id,
            createdByImageUrl: (0, util_1.generateImageUrl)({ email: event.createdBy }),
        }));
        const owners = await this.projectOwnersReadModel.getProjectOwners(projectId);
        const allRoles = await this.accessStore.getAllProjectRolesForUser(userId, projectId);
        const projectRoles = allRoles
            .filter((role) => ['project', 'custom'].includes(role.type))
            .map((role) => ({
            id: role.id,
            name: role.name,
            type: role.type,
        }));
        return {
            latestEvents: formattedEvents,
            onboardingStatus,
            owners,
            roles: projectRoles,
        };
    }
    async getAdmins() {
        return this.accountStore.getAdmins();
    }
}
exports.PersonalDashboardService = PersonalDashboardService;
//# sourceMappingURL=personal-dashboard-service.js.map